@@ -1,18 +1,18 @@
 var indexSectionsWithContent =
 {
   0: "abcdefghijklmnopqrstuvwxyz~",
-  1: "abcdefghijklmnoprstuvw",
+  1: "abcdefghijklmoprstuvw",
   2: "s",
-  3: "g",
+  3: "abcdefghijklmnoprstuvw",
   4: "abcdefghiklmnoprstuvwz~",
-  5: "abcdfghijklmnoprstuvwxyz",
-  6: "bcimv",
+  5: "abcdfgijklmnoprstuvwxyz",
+  6: "bcdefgimoprstuvw",
   7: "abcefkmpstuw",
   8: "abcdefghijklmnopqrstuvwxyz",
-  9: "o",
+  9: "dhorstuw",
   10: "s",
   11: "agmnsw",
-  12: "dls"
+  12: "ds"
 };
 
 var indexSectionNames =
